summaryrefslogtreecommitdiffstatshomepage
diff options
context:
space:
mode:
author Zsolt Vasvari <zsoltvas@mamedev.org>2008-03-12 11:47:57 +0000
committer Zsolt Vasvari <zsoltvas@mamedev.org>2008-03-12 11:47:57 +0000
commit4bd4eceb06ddcc1474cdf95b5094229ae38ef2c5 (patch)
tree38f7a008fa6609b50e325f578185135fe37753ae
parent839e3f073ca2fc6e2287eb89ebeb1bdbd09d05f7 (diff)
Forgot to state save a variable
-rw-r--r--src/emu/video.c4
1 files changed, 3 insertions, 1 deletions
diff --git a/src/emu/video.c b/src/emu/video.c
index fbc32ed2090..2be8c902981 100644
--- a/src/emu/video.c
+++ b/src/emu/video.c
@@ -357,6 +357,8 @@ void video_init(running_machine *machine)
state_save_register_item(unique_tag, 0, internal_state->vblank_start_time.seconds);
state_save_register_item(unique_tag, 0, internal_state->vblank_start_time.attoseconds);
+ state_save_register_item(unique_tag, 0, internal_state->vblank_end_time.seconds);
+ state_save_register_item(unique_tag, 0, internal_state->vblank_end_time.attoseconds);
state_save_register_item(unique_tag, 0, internal_state->frame_number);
}
@@ -1086,7 +1088,7 @@ attotime video_screen_get_time_until_vblank_end(const device_config *screen)
if (attotime_compare(current_time, internal_state->vblank_end_time) < 0)
ret = attotime_sub(internal_state->vblank_end_time, current_time);
/* otherwise computer the time until the next VBLANK period */
else
ret = attotime_sub(attotime_add_attoseconds(internal_state->vblank_end_time, internal_state->frame_period), current_time);
@@ -1086,7 +1088,7 @@ attotime video_screen_get_time_until_vblank_end(const device_config *screen)
if (attotime_compare(current_time, internal_state->vblank_end_time) < 0)
ret = attotime_sub(internal_state->vblank_end_time, current_time);
- /* otherwise computer the time until the next VBLANK period */
+ /* otherwise compute the time until the end of the next frame VBLANK period */
else
ret = attotime_sub(attotime_add_attoseconds(internal_state->vblank_end_time, internal_state->frame_period), current_time);